from distutils.core import setup

setup(
		name="nesterlist",
		version="1.0.0",
		py_modules=["nesterlist"],
		author="Fred",
		author_email="shuishuiwawa@gmail.com",
		url="https//localhost",
		description="It is a function to print nested list.",
		license="Apache"
		)
